@@ -23,7 +23,11 @@ def find_path(name, config, wsonly=False):
 
     if name.find('/') != -1:
         wsonly = False
-        ws, repo = name.split('/')
+        try:
+            ws, repo = name.split('/')
+        except ValueError:
+            raise ValueError("There is too many / in `name` argument. "
+                             "Argument syntax: `workspace/repository`.")
         if (workspace.exists(ws)):
             if (repo in config[ws]["repositories"]):
                 path_name = "%s/%s" % (ws, repo)
@@ -45,6 +49,11 @@ def find_path(name, config, wsonly=False):
     return path_list
 
 
+def slashes2dash(string):
+    """Replace slashes in given string to dash."""
+    return string.replace("/", "-")
+
+
 def yn_choice(message, default='n'):
     choices = 'Y/n' if default.lower() in ('y', 'yes') else 'y/N'
     choice = input("%s (%s) " % (message, choices))
